@@ -1,11 +1,11 @@
 import sys
 import types
 
-from je_auto_control import press_key, release_key, hotkey, type_key, write, record, stop_record
-from je_auto_control import locate_all_image, locate_and_click, locate_image_center
 from je_auto_control import check_key_is_press, position, press_mouse, release_mouse, click_mouse, scroll
-from je_auto_control import set_position
+from je_auto_control import locate_all_image, locate_and_click, locate_image_center
+from je_auto_control import press_key, release_key, hotkey, type_key, write, record, stop_record
 from je_auto_control import screenshot, size
+from je_auto_control import set_position
 from je_auto_control.utils.exception.exception_tag import action_is_null_error, add_command_exception_tag, \
     executor_list_error
 from je_auto_control.utils.exception.exception_tag import cant_execute_action_error
@@ -73,13 +73,13 @@ class Executor(object):
         :param action_list the list include action
         for loop the list and execute action
         """
-        if type(action_list) is dict:
+        if isinstance(action_list, dict):
             action_list: list = action_list.get("auto_control", None)
             if action_list is None:
                 raise AutoControlActionNullException(executor_list_error)
         execute_record_dict = dict()
         try:
-            if len(action_list) > 0 or type(action_list) is list:
+            if len(action_list) > 0 or isinstance(action_list, list):
                 pass
             else:
                 raise AutoControlActionNullException(action_is_null_error)
